<?php
namespace Folha\Logic\ESocial\Eventos\Data;
use Folha\Repositories\GpeEsocialRegistro;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-1340 - Serviços Prestados pela Cooperativa de
 * Trabalho.
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S1340
{

    /**
     * Retorna os dados que serao utilizado para a geracao do(s) arquivo(s) do evento S-1340, Serviços Prestados pela
     * Cooperativa de Trabalho.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $idRetificacao           Identificador de Retificação dos arquivos ou não.
     * @param $nrRecibo                Número do Recibo do primeiro envio em caso de Retificação.
     * @param $idApuracao              Identificador da apuração Mensal ou Anual.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao)
    {
        $S1340 = GpeEsocialRegistro::dataSetEsocial_S1340(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao
        );

        // Loop para gerar os estabelecimentos referentes ao empregador acima
        foreach ($S1340 as &$row) {
            $prests = GpeEsocialRegistro::s13xx_EstabPrestTomad('S', $row['NRESTRUTURAM'], $inicioPeriodo, $fimPeriodo, $nrorg);

            // Loop para gerar os contratantes referentes ao estabelecimento acima
            $contPrest = 1;
            $prestador = null;
            foreach($prests as &$prest) {
                $contrats = GpeEsocialRegistro::s13xx_PrestadTomador('S', $prest['CDFILIEMIT'], $inicioPeriodo, $fimPeriodo, null);

                // Loop para gerar as notas referentes ao prestador acima
                $contContr = 1;
                $contratante = null;
                foreach($contrats as &$contrat) {
                    $notas = GpeEsocialRegistro::s13xx_NfServPrestTomad('S', $contrat['CDFILIEMIT'], $prest['CDCLIENTE'], $inicioPeriodo, $fimPeriodo);

                    // Loop para gerar os itens referentes à nota acima
                    $contNF = 1;
                    $nfEmitidas = null;
                    foreach ($notas as &$notafiscal) {
                        $nfEmitidas[$contNF] =
                            array("_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS" => '1',
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_SERIE" => $notafiscal['SERIE'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_NUMDOCTO" => $notafiscal['NUMDOCTO'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_DTEMISSAONF" => $notafiscal['DTEMISSAONF'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_DTPAGTONF" => $notafiscal['INDOBRA'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_INDOBRA" => $notafiscal['NRCNO'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_NRCNO" => $notafiscal['NRCNO'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRBRUTO" => $notafiscal['VLRBRUTO'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRMATEQUIP" => $notafiscal['VLRSERVICOS'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRSERVICOS" => $notafiscal['VLRDEDUCOES'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRDEDUCOES" => $notafiscal['VLRBASERETENCAO'],
                                "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRBASECOOP" => $notafiscal['VLRRETENCAOAPURADA']);
                        $contNF++;
                    }

                    $contratante[$contContr] =
                        array("_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE" => '1',
                            "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_TPINSCCONTRATANTE" => $contrat['TPINSCCONTRATANTE'],
                            "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NRINSCCONTRATANTE" => $contrat['NRINSCCONTRATANTE'],
                            "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRBRUTO" => $contrat['VLRBRUTO'],
                            "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRBASECOOP" => $contrat['VLRBASECOOP'],
                            "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS" => $nfEmitidas);
                    $contContr++;
                }

                $prestador[$contPrest] =
                    array("_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR" => '1',
                        "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_TPINSCRICAO" => $prest['ESTABTPINSCRICAO'],
                        "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_NRINSCRICAO" => $prest['ESTABNRINSCRICAO'],
                        "_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE" => $contratante);
                $contPrest++;
            }

            $row['_EVTFPSERVPRESTADOSCOOP_INFOSERVPRESTADOS_IDEESTABPRESTADOR'][1] = $prestador;
        }

        return $S1340;
    }

}